@@ -61,7 +61,7 @@ extern "C"
 
 #include <tdeglobal.h>
 #include <tdelocale.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdefilemetainfo.h>
 #include <kmimetype.h>
 #include <kdebug.h>
